# -*- coding: utf-8 -*-
#
# Copyright (C) 2019 James E. King III (@jeking3) <jking@apache.org>
#
__author__ = "James E. King III"
__copyright__ = "Copyright (C) 2019 James E. King III (@jeking3) <jking@apache.org>"
__license__ = "Apache Software License, Version 2.0"
__version__ = "0.1.0"
